# lsm303d examples

## accelerometer.py

Reads the X, Y and Z axis acceleration-in-g values from the lsm303d accelerometer.

## magnetometer.py

Reads the X, Y and Z axis magnetic gauss values from the lsm303d accelerometer.
